@@ -80,13 +80,17 @@
 #define USB_DEVICE_ID_RAZER_ORNATA_V2 0x025D
 #define USB_DEVICE_ID_RAZER_CYNOSA_V2 0x025E
 #define USB_DEVICE_ID_RAZER_HUNTSMAN_V2_ANALOG 0x0266
+#define USB_DEVICE_ID_RAZER_HUNTSMAN_MINI_JP 0x0269
 #define USB_DEVICE_ID_RAZER_BOOK_2020 0x026A
+#define USB_DEVICE_ID_RAZER_HUNTSMAN_V2 0x026C
 #define USB_DEVICE_ID_RAZER_BLADE_15_ADV_EARLY_2021 0x026D
 #define USB_DEVICE_ID_RAZER_BLADE_15_BASE_EARLY_2021 0x026F
 #define USB_DEVICE_ID_RAZER_BLADE_14_2021 0x0270
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_MINI_WIRELESS 0x0271
 #define USB_DEVICE_ID_RAZER_BLADE_15_ADV_MID_2021 0x0276
 #define USB_DEVICE_ID_RAZER_BLADE_17_PRO_MID_2021 0x0279
+#define USB_DEVICE_ID_RAZER_BLADE_15_ADV_EARLY_2022 0x028A
+#define USB_DEVICE_ID_RAZER_BLADE_17_2022 0x028B
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_TK 0x0A24
 
 /* Each keyboard report has 90 bytes*/
