@@ -1,6 +1,9 @@
 #!/bin/bash
 
 declare -A files_metadata=(
+    ["backlight_led_brightness"]="rw;0"
+    ["backlight_led_effect"]="rw;0"
+    ["backlight_led_rgb"]="rw;0xFF00FF"
     ["backlight_led_state"]="rw;0"
     ["charge_colour"]="w;"
     ["charge_effect"]="w;"
@@ -89,6 +92,9 @@ declare -A files_metadata=(
     ["scroll_matrix_effect_spectrum"]="w;"
     ["scroll_matrix_effect_static"]="w;"
     ["scroll_matrix_effect_wave"]="w;"
+    ["scroll_mode"]="rw;0"
+    ["scroll_acceleration"]="rw;0"
+    ["scroll_smart_reel"]="rw;0"
     ["tilt_hwheel"]="rw;0"
     ["tilt_repeat"]="rw;0"
     ["tilt_repeat_delay"]="rw;0"
